# eric7.WebBrowser.Navigation.ReloadStopButton

Module implementing a button alternating between reload and stop.

### Global Attributes

None

### Classes

ReloadStopButton | Class implementing a button alternating between reload and stop.

### Functions

None

## ReloadStopButton

Class implementing a button alternating between reload and stop.

### Signals

reloadClicked()
  emitted to initiate a reload action
stopClicked()
  emitted to initiate a stop action

### Derived from

EricToolButton

### Class Attributes

None

### Class Methods

None

### Methods

ReloadStopButton | Constructor
__buttonClicked | Private slot handling a user clicking the button.
__updateButton | Private slot to update the button.
setLoading | Public method to set the loading state.

### Static Methods

None

#### ReloadStopButton (Constructor)

ReloadStopButton(parent=None)

Constructor

parent (QWidget)
  reference to the parent widget

#### ReloadStopButton.__buttonClicked

__buttonClicked()

Private slot handling a user clicking the button.

#### ReloadStopButton.__updateButton

__updateButton()

Private slot to update the button.

#### ReloadStopButton.setLoading

setLoading(loading)

Public method to set the loading state.

loading (bool)
  flag indicating the new loading state

Up